@@ -65,5 +65,5 @@ class TwitterAccessToken(AccessTokenBase):
         except:
             raise Exception("Wrong response on authorization post request for user %s" % self.auth_request.username)
 
-        log.debug('Got twitter verifier: %s for user %s' % (code, self.oauth_request.username))
+        log.debug('Got twitter verifier: %s for user %s' % (code, self.auth_request.username))
         return str(code)
